summaryrefslogtreecommitdiffstats
path: root/kbabel/catalogmanager/libcvs/cvshandler.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/catalogmanager/libcvs/cvshandler.cpp')
-rw-r--r--kbabel/catalogmanager/libcvs/cvshandler.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/kbabel/catalogmanager/libcvs/cvshandler.cpp b/kbabel/catalogmanager/libcvs/cvshandler.cpp
index 6ab70423..b0764af8 100644
--- a/kbabel/catalogmanager/libcvs/cvshandler.cpp
+++ b/kbabel/catalogmanager/libcvs/cvshandler.cpp
@@ -182,18 +182,18 @@ TQString CVSHandler::cvstqStatus( const TQString& filename ) const
return map[filename];
}
-void CVSHandler::execCVSCommand( TQWidget* tqparent, CVS::Command cmd, const TQString& filename, bool templates, KSharedConfig* config )
+void CVSHandler::execCVSCommand( TQWidget* parent, CVS::Command cmd, const TQString& filename, bool templates, KSharedConfig* config )
{
if ( !_isPORepository ) {
// This message box should never be visible but who knows... ;-)
- KMessageBox::sorry( tqparent, i18n( "This is not a valid CVS repository. "
+ KMessageBox::sorry( parent, i18n( "This is not a valid CVS repository. "
"The CVS commands cannot be executed." ) );
return;
}
TQFileInfo info( filename );
if ( !info.isDir( ) ) {
- execCVSCommand( tqparent, cmd, TQStringList( filename ), templates, config );
+ execCVSCommand( parent, cmd, TQStringList( filename ), templates, config );
return;
}
@@ -218,14 +218,14 @@ void CVSHandler::execCVSCommand( TQWidget* tqparent, CVS::Command cmd, const TQS
break;
}
- showDialog( tqparent, cmd, TQStringList( filename ), command, config );
+ showDialog( parent, cmd, TQStringList( filename ), command, config );
}
-void CVSHandler::execCVSCommand( TQWidget* tqparent, CVS::Command cmd, const TQStringList& files, bool templates, KSharedConfig* config )
+void CVSHandler::execCVSCommand( TQWidget* parent, CVS::Command cmd, const TQStringList& files, bool templates, KSharedConfig* config )
{
if ( !_isPORepository ) {
// This message box should never be visible but who knows... ;-)
- KMessageBox::sorry( tqparent, i18n( "This is not a valid CVS repository. "
+ KMessageBox::sorry( parent, i18n( "This is not a valid CVS repository. "
"The CVS commands cannot be executed." ) );
return;
}
@@ -262,7 +262,7 @@ void CVSHandler::execCVSCommand( TQWidget* tqparent, CVS::Command cmd, const TQS
command += " \'" + temp + "\'";
}
- showDialog( tqparent, cmd, files, command, config );
+ showDialog( parent, cmd, files, command, config );
}
void CVSHandler::setAutoUpdateTemplates( bool update )
@@ -270,9 +270,9 @@ void CVSHandler::setAutoUpdateTemplates( bool update )
_autoUpdateTemplates = update;
}
-void CVSHandler::showDialog( TQWidget* tqparent, CVS::Command cmd, const TQStringList& files, const TQString& commandLine, KSharedConfig* config )
+void CVSHandler::showDialog( TQWidget* parent, CVS::Command cmd, const TQStringList& files, const TQString& commandLine, KSharedConfig* config )
{
- CVSDialog * dia = new CVSDialog( cmd, tqparent, config );
+ CVSDialog * dia = new CVSDialog( cmd, parent, config );
dia->setFiles( files );
dia->setCommandLine( commandLine );
if ( cmd == CVS::Commit ) {
@@ -313,7 +313,7 @@ void CVSHandler::checkToAdd( const TQStringList& files )
toBeAdded << *it;
temp = TQFileInfo( *it ).dirPath( true );
}
// check recursivlely if tqparent dirs have to be added as well
while ( fstatus( temp ) == NOT_IN_CVS && toBeAdded.findIndex( temp ) == -1 ) {
toBeAdded << temp;
temp = TQFileInfo( temp ).dirPath( true );
@@ -313,7 +313,7 @@ void CVSHandler::checkToAdd( const TQStringList& files )
temp = TQFileInfo( *it ).dirPath( true );
}
- // check recursivlely if tqparent dirs have to be added as well
+ // check recursivlely if parent dirs have to be added as well
while ( fstatus( temp ) == NOT_IN_CVS && toBeAdded.findIndex( temp ) == -1 ) {
toBeAdded << temp;